<?php

/**
 * These files are included as needed to reduce overhead.
 * See the README for additional information.
 */

/**
 * Basic definition of the content type. API element.
 */
function mysite_type_theme($get_options = TRUE) {
  $type = array(
    'name' => t('theme'),
    'description' => t('<b>Theme Switching</b>: This is an admin setting only. Enable it to alliow users to switch themes.'),
    'include' => 'theme',
    'weight' => 0,
    'form' => FALSE,
  );
  if ($get_options) {
    $type['options'] = array();
  }
  return $type;
}

/**
 * Settings for this type
 */
function mysite_type_theme_settings() {
  return drupal_get_form('mysite_type_theme_settings_form');
}

/** 
 * FormsAPI for mysite_type_theme_settings
 */
function mysite_type_theme_settings_form() {
  $themes = system_theme_data();
  $options = array();
  foreach ($themes as $info) {
    if ($info->status) {
      $info->screenshot = dirname($info->filename) .'/screenshot.png';
      $screenshot = file_exists($info->screenshot) ? theme('image', $info->screenshot, t('Screenshot for %theme theme', array('%theme' => $info->name)), '', array('class' => 'screenshot'), FALSE) : t('no screenshot');
      $options[$info->name] = ucwords(str_replace('_', ' ', $info->name)) . '<p>' . $screenshot . '</p>';
    }
  }
  $form['mysite_theme_settings'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Allowed themes'),
    '#default_value' => variable_get('mysite_theme_settings', array()),
    '#options' => $options,
    '#required' => FALSE,
    '#description' => t('Select the themes that users may select for their MySite page.')
  );      

  return system_settings_form($form);          
}

/**
 * Build the form element for the user selection of themes
 */
 function mysite_type_theme_list($themes = array()) {
  $default = system_theme_data();
  $options = array();
  foreach ($default as $info) {
    if ($info->status && !empty($themes[$info->name])) {
      $info->screenshot = dirname($info->filename) .'/screenshot.png';
      $screenshot = file_exists($info->screenshot) ? theme('image', $info->screenshot, t('Screenshot for %theme theme', array('%theme' => $info->name)), '', array('class' => 'screenshot'), FALSE) : t('no screenshot');
      $options[$info->name] = ucwords(str_replace('_', ' ', $info->name)) . '<p>' . $screenshot . '</p>';
    }
  }
  return $options;
}